namespace Votations.NSurvey.SQLServerDAL
{
    using Microsoft.ApplicationBlocks.Data;
    using System;
    using System.Data;
    using System.Data.SqlClient;
    using Votations.NSurvey.Data;
    using Votations.NSurvey.IDAL;

    /// <summary>
    /// SQL Server DAL implementation.
    /// </summary>
    public class Filter : Votations.NSurvey.IDAL.IFilter
    {
        /// <summary>
        /// Adds a new filter
        /// </summary>
        /// <param name="newFilter"></param>
        public void AddFilter(FilterData newFilter)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spFilterAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@SurveyId", SqlDbType.Int, 4, "SurveyId"));
            insertCommand.Parameters.Add(new SqlParameter("@Description", SqlDbType.VarChar, 200, "Description"));
            insertCommand.Parameters.Add(new SqlParameter("@LogicalOperatorTypeID", SqlDbType.Int, 4, "LogicalOperatorTypeID"));
            insertCommand.Parameters.Add(new SqlParameter("@FilterId", SqlDbType.Int, 4, "FilterId"));
            insertCommand.Parameters["@FilterId"].Direction = ParameterDirection.Output;
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), newFilter, "Filters", true);
        }

        /// <summary>
        /// Adds a new filter rule
        /// </summary>
        /// <param name="newRule"></param>
        public void AddRule(FilterRuleData newRule)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spFilterRuleAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@FilterId", SqlDbType.Int, 4, "FilterID"));
            insertCommand.Parameters.Add(new SqlParameter("@AnswerId", SqlDbType.Int, 4, "AnswerId"));
            insertCommand.Parameters.Add(new SqlParameter("@QuestionId", SqlDbType.Int, 4, "QuestionId"));
            insertCommand.Parameters.Add(new SqlParameter("@TextFilter", SqlDbType.NVarChar, 0xfa0, "TextFilter"));
            insertCommand.Parameters.Add(new SqlParameter("@FilterRuleID", SqlDbType.Int, 4, "FilterRuleID"));
            insertCommand.Parameters["@FilterRuleID"].Direction = ParameterDirection.Output;
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), newRule, "FilterRules", true);
        }

        /// <summary>
        /// Deletes the given filter
        /// </summary>
        /// <param name="filterId"></param>
        public void DeleteFilter(int filterId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spFilterDelete", new SqlParameter[] { new SqlParameter("@FilterId", filterId) });
        }

        /// <summary>
        /// Deletes the given filter rule
        /// </summary>
        /// <param name="ruleId"></param>
        public void DeleteRule(int ruleId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spFilterRuleDelete", new SqlParameter[] { new SqlParameter("@FilterRuleId", ruleId) });
        }

        public FilterData GetFilterById(int filterId)
        {
            FilterData dataSet = new FilterData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spFilterGetDetails", dataSet, new string[] { "Filters" }, new SqlParameter[] { new SqlParameter("@FilterID", filterId) });
            return dataSet;
        }

        public FilterData GetFilters(int surveyId)
        {
            FilterData dataSet = new FilterData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spFilterGetForSurvey", dataSet, new string[] { "Filters" }, new SqlParameter[] { new SqlParameter("@SurveyID", surveyId) });
            return dataSet;
        }

        public FilterRuleData GetRulesForFilter(int filterId)
        {
            FilterRuleData dataSet = new FilterRuleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spFilterRuleGetForFilter", dataSet, new string[] { "FilterRules" }, new SqlParameter[] { new SqlParameter("@FilterID", filterId) });
            return dataSet;
        }

        /// <summary>
        /// Update the filter options
        /// </summary>
        /// <param name="updatedFilter"></param>
        public void UpdateFilter(FilterData updatedFilter)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spFilterUpdate", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@FilterId", SqlDbType.Int, 4, "FilterId"));
            insertCommand.Parameters.Add(new SqlParameter("@Description", SqlDbType.VarChar, 200, "Description"));
            insertCommand.Parameters.Add(new SqlParameter("@LogicalOperatorTypeID", SqlDbType.SmallInt, 4, "LogicalOperatorTypeID"));
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), insertCommand, updatedFilter, "Filters", false);
        }
    }
}

