namespace Votations.NSurvey.SQLServerDAL
{
    using Microsoft.ApplicationBlocks.Data;
    using System;
    using System.Data;
    using System.Data.SqlClient;
    using Votations.NSurvey.Data;
    using Votations.NSurvey.IDAL;

    /// <summary>
    /// SQL Server DAL implementation.
    /// </summary>
    public class Role : IRole
    {
        /// <summary>
        /// Adds a new right to a role
        /// </summary>
        public void AddRightToRole(int roleId, int securityRightId)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@RoleID", roleId), new SqlParameter("@SecurityRightId", securityRightId) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spRoleSecurityRightAddNew", commandParameters);
        }

        /// <summary>
        /// Adds a new role to the database
        /// </summary>
        public void AddRole(RoleData newRole)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spRoleAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@RoleName", SqlDbType.VarChar, 0xff, "RoleName"));
            insertCommand.Parameters.Add(new SqlParameter("@RoleId", SqlDbType.Int, 4, "RoleId"));
            insertCommand.Parameters["@RoleId"].Direction = ParameterDirection.Output;
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), newRole, "Roles", true);
        }

        /// <summary>
        /// Add a new role to the user
        /// </summary>
        public void AddRoleToUser(int roleId, int userId)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@RoleID", roleId), new SqlParameter("@UserId", userId) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserRoleAssignUser", commandParameters);
        }

        /// <summary>
        /// Remove the role 
        /// </summary>
        public void DeleteRoleById(int roleId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spRoleDelete", new SqlParameter[] { new SqlParameter("@RoleId", roleId) });
        }

        /// <summary>
        /// delete a role's rights
        /// </summary>
        public void DeleteRoleRights(int roleId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spRoleSecurityRightDeleteAll", new SqlParameter[] { new SqlParameter("@RoleId", roleId) });
        }

        /// <summary>
        /// Deletes a user's role
        /// </summary>
        public void DeleteUserRole(int roleId, int userId)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@RoleID", roleId), new SqlParameter("@UserId", userId) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserRoleUnAssignUser", commandParameters);
        }

        /// <summary>
        /// Retrieves all role from the database
        /// </summary>
        public RoleData GetAllRolesList()
        {
            RoleData dataSet = new RoleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spRoleGetList", dataSet, new string[] { "Roles" });
            return dataSet;
        }

        /// <summary>
        /// Retrieves role details from the database
        /// </summary>
        public RoleData GetRoleById(int roleId)
        {
            RoleData dataSet = new RoleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spRoleGetDetails", dataSet, new string[] { "Roles", "SecurityRights" }, new SqlParameter[] { new SqlParameter("@RoleId", roleId) });
            return dataSet;
        }

        /// <summary>
        /// Retrieves all role from the database assigned to a user
        /// </summary>
        public RoleData GetRolesOfUser(int userId)
        {
            RoleData dataSet = new RoleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserRoleGetAssignedList", dataSet, new string[] { "Roles" }, new SqlParameter[] { new SqlParameter("@UserId", userId) });
            return dataSet;
        }

        /// <summary>
        /// Retrieves role details from the database
        /// </summary>
        public SecurityRightData GetSecurityRightList()
        {
            SecurityRightData dataSet = new SecurityRightData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSecurityRightGetList", dataSet, new string[] { "SecurityRights" });
            return dataSet;
        }

        /// <summary>
        /// Retrieves all role from the database not assigned to a user
        /// </summary>
        public RoleData GetUnassignedRolesToUser(int userId)
        {
            RoleData dataSet = new RoleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserRoleGetUnAssignedList", dataSet, new string[] { "Roles" }, new SqlParameter[] { new SqlParameter("@UserId", userId) });
            return dataSet;
        }

        /// <summary>
        /// Updates roles data
        /// </summary>
        public void UpdateRole(RoleData updatedRole)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spRoleUpdate", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@RoleId", SqlDbType.Int, 4, "RoleId"));
            insertCommand.Parameters.Add(new SqlParameter("@RoleName", SqlDbType.VarChar, 0xff, "RoleName"));
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), updatedRole, "Roles", true);
        }
    }
}

