/**************************************************************************************************

	NSurvey - The web survey and form engine
	Copyright (c) 2004, 2005 Thomas Zumbrunn. (http://www.nsurvey.org)

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

************************************************************************************************/
using System;
using System.Data;
using System.Data.SqlClient;
using Microsoft.ApplicationBlocks.Data;
using Votations.NSurvey;
using Votations.NSurvey.Data;
using Votations.NSurvey.IDAL;
using System.Collections.Generic;
using System.Linq;
namespace Votations.NSurvey.SQLServerDAL
{
    /// <summary>
    /// SQL Server DAL implementation.
    /// </summary>
    public class Survey : ISurvey
    {
        /// <summary>
        /// 
        /// </summary>
        /// <param name="folderId"></param>
        /// <returns></returns>
        public SurveyData GetAllSurveysByFolderId(int? folderId)
        {
            SurveyData surveyData = new SurveyData();

            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetListByFolderId", surveyData, new string[] { "Surveys" }, new SqlParameter("@FolderID", folderId));

            return surveyData;
        }

        public SurveyData GetAllSurveys()
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetAllDetails", surveyData, new string[] { "Surveys" });
            return surveyData;
        }

        /// <summary>
        /// Get a survey list with only the survey id and title
        /// </summary>
        /// <returns></returns>
        public SurveyData GetAllSurveysList()
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetList", surveyData, new string[] { "Surveys" });
            return surveyData;
        }

        /// <summary>
        /// Get a survey list with only the survey id and title with matching title
        /// </summary>
        /// <returns></returns>
        public SurveyData GetAllSurveysByTitle(string title, int? folderID, int userID)
        {
            SurveyData surveyData = new SurveyData();
            SqlParameter[] spParameters = new SqlParameter[3];
            spParameters[0] = new SqlParameter("@SurveyTitle", title);
            spParameters[1] = new SqlParameter("@FolderId", folderID);
            spParameters[2] = new SqlParameter("@UserId", userID);

            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetListByTitle", surveyData, new string[] { "Surveys" }, spParameters);
            return surveyData;
        }


        /// <summary>
        /// Clone the given survey and returns its clone
        /// </summary>
        /// <param name="surveyId">Id of the survey you want to clone</param>
        /// <returns>A SurveyData dataset object with the current database values of the clone</returns>
        public SurveyData CloneSurvey(int surveyId)
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyClone", surveyData, new string[] { "Surveys" }, new SqlParameter("@SurveyID", surveyId));
            return surveyData;
        }


        /// <summary>
        /// Get all surveys that have been flaged as archived
        /// </summary>
        public SurveyData GetArchivedSurveys()
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveysGetArchive", surveyData, new string[] { "Surveys" });
            return surveyData;
        }

        /// <summary>
        /// Return a survey object that reflects the database survey
        /// </summary>
        /// <param name="surveyId">Id of the survey you need</param>
        /// <returns>A survey object with the current database values</returns>
        public SurveyData GetSurveyById(int surveyId, string languageCode)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@LanguageCode", languageCode);

            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetDetails", surveyData, new string[] { "Surveys" }, spParameters);
            return surveyData;
        }

        /// <summary>
        /// Check if a survey exists in the database
        /// </summary>
        /// <returns>true if the survey exists</returns>
        public bool SurveyExists(string title)
        {
            if (SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyExists", new SqlParameter("@Title", title)) != null)
                return true;
            else
                return false;
        }

        /// <summary>
        /// Check if the given password is valid for the survey
        /// </summary>
        /// <param name="surveyId">Id of the protected survey</param>
        /// <param name="password">the password to check for</param>
        public bool IsSurveyPasswordValid(int surveyId, string password)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@password", password);

            if (SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyValidatePassword", spParameters) != null)
                return true;
            else
                return false;
        }

        /// <summary>
        /// Return a survey object that reflects the current activated survey. 
        /// IE: The survey that shows up when the surveybox has a surveyid value of 
        /// 0
        /// </summary>
        /// <returns>A survey object with the current database values</returns>
        public SurveyData GetActivatedSurvey()
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetActivated", surveyData, new string[] { "Surveys" });
            return surveyData;
        }

        /// <summary>
        /// Get a survey list not assigned to the user
        /// </summary>
        /// <returns></returns>
        public SurveyData GetUnAssignedSurveysList(int userId)
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetUnAssignedListForUser", surveyData, new string[] { "Surveys" }, new SqlParameter("@UserId", userId));
            return surveyData;
        }

        /// <summary>
        /// Get a survey list assigned to the user
        /// </summary>
        /// <returns></returns>
        public SurveyData GetAssignedSurveysList(int userId)
        {
            SurveyData surveyData = new SurveyData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetAssignedListForUser", surveyData, new string[] { "Surveys" }, new SqlParameter("@UserId", userId));
            return surveyData;
        }


        /// <summary>
        /// Returns the total of surveys stored in the database
        /// </summary>
        /// <returns>Total of surveys</returns>
        public int TotalOfSurveys()
        {
            return int.Parse(SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spGetSurveyTotal").ToString());
        }


        /// <summary>
        /// Remove the survey and all its question / answers from the database
        /// </summary>
        /// <param name="surveyId">Survey to delete from the database</param>
        public void DeleteSurveyById(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyDeleteById", new SqlParameter("@SurveyID", surveyId));
        }

        /// <summary>
        /// Sets all answers and vote count to 0
        /// </summary>
        /// <param name="surveyId">Survey ID</param>
        public void ResetVotes(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyResetVotes", new SqlParameter("@SurveyID", surveyId));
        }

        /// <summary>
        /// Assigns a new user to a survey
        /// </summary>
        public void AssignUserToSurvey(int surveyId, int userId)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@UserId", userId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserSurveyAssignUser", spParameters);
        }

        /// <summary>
        /// UnAssigns a user from a survey
        /// </summary>
        public void UnAssignUserFromSurvey(int surveyId, int userId)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@UserId", userId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserSurveyUnAssignUser", spParameters);
        }

        /// <summary>
        /// Insert a new page break
        /// </summary>
        /// <param name="surveyId">Survey ID</param>
        /// <param name="displayOrder">Where we will insert the page break</param>
        public void InsertPageBreak(int surveyId, int displayOrder)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@DisplayOrder", displayOrder);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyInsertPageBreak", spParameters);
        }
        /// <summary>
        /// Move a page break up
        /// </summary>
        /// <param name="surveyId">ID of the survey to which we add the page break</param>
        /// <param name="pageNumber">Page break to move up</param>
        public void MovePageBreakUp(int surveyId, int pageNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@PageNumber", pageNumber);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyMovePageBreakUp", spParameters);
        }

        /// <summary>
        /// Move a page break Down
        /// </summary>
        /// <param name="surveyId">ID of the survey to which we add the page break</param>
        /// <param name="pageNumber">Page break to move down</param>
        public void MovePageBreakDown(int surveyId, int pageNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@PageNumber", pageNumber);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyMovePageBreakDown", spParameters);
        }

        /// <summary>
        /// Deletes a page break
        /// </summary>
        /// <param name="surveyId">Survey ID</param>
        /// <param name="pageNumber">Page numbe to delete</param>
        public void DeletePageBreak(int surveyId, int pageNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@PageNumber", pageNumber);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyDeletePageBreak", spParameters);
        }

        /// <summary>
        /// Retrieves the first survey ID available in the DB
        /// </summary>
        /// <returns>
        /// If found the survey ID else -1
        /// </returns>
        public int GetFirstSurveyId()
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetFirstID");
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return -1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }

        /// <summary>
        /// Retrieves the first survey ID for user available in the DB
        /// </summary>
        /// <returns>
        /// If found the survey ID else -1
        /// </returns>
        public int GetFirstSurveyId(int userId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetFirstIDForUser", new SqlParameter("@UserId", userId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return -1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }

        /// <summary>
        /// Check if the user has this survey assigned
        /// </summary>
        public bool CheckSurveyUser(int surveyId, int userId)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@UserId", userId);

            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyCheckUserAssigned", spParameters);
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return true;
            }
        }

        /// <summary>
        /// Returns the total of pages in the survey
        /// </summary>
        /// <param name="surveyId"></param>
        /// <returns></returns>
        public int GetPagesNumber(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetPagesNumber", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return 1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }
        /// <summary>
        /// Returns the total of pages in the survey
        /// </summary>
        /// <param name="surveyId"></param>
        /// <returns></returns>
        public int GetSurveyIdFromGuid(Guid id)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetSurveyIdFromGuid", new SqlParameter("@SurveyGuID", id));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return -1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }
        public int GetSurveyIdFromFriendlyName(string name)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetSurveyIdFromFriendlyName", new SqlParameter("@FriendlyName", name));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return -1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }

        /// <summary>
        /// Adds a new survey to the database
        /// </summary>
        /// <param name="newSurvey">Survey object with information about what to add. Only Id must be ommited</param>
        public void AddSurvey(SurveyData newSurvey)
        {

            try
            {
                SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
                SqlCommand addNewSurvey = GetInsertSurveyCommand(dbConnection, null);
                SqlHelper.UpdateDataset(addNewSurvey, new SqlCommand(), new SqlCommand(), newSurvey, "Surveys", true);
            }
            catch (SqlException ex)
            {
                if (ex.Message == "DUPLICATEFOLDER") throw new SurveyExistsFoundException();
                throw;
            }
        }

        /// <summary>
        /// Creates and return an insert command for a survey
        /// </summary>
        public SqlCommand GetInsertSurveyCommand(SqlConnection sqlConnection,
            SqlTransaction sqlTransaction)
        {
            SqlCommand addNewSurvey = (sqlTransaction == null) ?
                new SqlCommand("vts_spSurveyAddNew", sqlConnection) : new SqlCommand("vts_spSurveyAddNew", sqlConnection, sqlTransaction);
            addNewSurvey.CommandType = CommandType.StoredProcedure;
            addNewSurvey.Parameters.Add(new SqlParameter("@CreationDate", DateTime.Now));
            addNewSurvey.Parameters.Add(new SqlParameter("@OpenDate", SqlDbType.DateTime, 8, "OpenDate"));
            addNewSurvey.Parameters.Add(new SqlParameter("@CloseDate", SqlDbType.DateTime, 8, "CloseDate"));
            addNewSurvey.Parameters.Add(new SqlParameter("@Title", SqlDbType.NVarChar, 255, "Title"));
            addNewSurvey.Parameters.Add(new SqlParameter("@AccessPassword", SqlDbType.VarChar, 255, "AccessPassword"));
            addNewSurvey.Parameters.Add(new SqlParameter("@SurveyDisplayTimes", SqlDbType.Int, 4, "SurveyDisplayTimes"));
            addNewSurvey.Parameters.Add(new SqlParameter("@ResultsDisplayTimes", SqlDbType.Int, 4, "ResultsDisplayTime"));
            addNewSurvey.Parameters.Add(new SqlParameter("@Archive", SqlDbType.Bit, 1, "Archive"));
            addNewSurvey.Parameters.Add(new SqlParameter("@Activated", SqlDbType.Bit, 1, "Activated"));
            addNewSurvey.Parameters.Add(new SqlParameter("@IPExpires", SqlDbType.Int, 4, "IPExpires"));
            addNewSurvey.Parameters.Add(new SqlParameter("@CookieExpires", SqlDbType.Int, 4, "CookieExpires"));
            addNewSurvey.Parameters.Add(new SqlParameter("@OnlyInvited", SqlDbType.Bit, 1, "OnlyInvited"));
            addNewSurvey.Parameters.Add(new SqlParameter("@Scored", SqlDbType.Bit, 1, "Scored"));
            addNewSurvey.Parameters.Add(new SqlParameter("@NavigationEnabled", SqlDbType.Bit, 1, "NavigationEnabled"));
            addNewSurvey.Parameters.Add(new SqlParameter("@ProgressDisplayModeId", SqlDbType.Int, 4, "ProgressDisplayModeId"));
            addNewSurvey.Parameters.Add(new SqlParameter("@ResumeModeId", SqlDbType.Int, 4, "ResumeModeId"));
            addNewSurvey.Parameters.Add(new SqlParameter("@QuestionNumberingDisabled", SqlDbType.Bit, 1, "QuestionNumberingDisabled"));
            addNewSurvey.Parameters.Add(new SqlParameter("@SurveyID", SqlDbType.Int, 4, "SurveyID"));
            addNewSurvey.Parameters.Add(new SqlParameter("@FolderId", SqlDbType.Int, 4, "FolderId"));
            addNewSurvey.Parameters["@SurveyID"].Direction = ParameterDirection.Output;

            return addNewSurvey;
        }


        /// <summary>
        /// Add a new branching rule to the survey
        /// </summary>
        public void AddBranchingRule(BranchingRuleData newBranchingRule)
        {

            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand addNewRule = new SqlCommand("vts_spSurveyBranchingRuleAddNew", dbConnection);
            addNewRule.CommandType = CommandType.StoredProcedure;
            addNewRule.Parameters.Add(new SqlParameter("@PageNumber", SqlDbType.Int, 4, "PageNumber"));
            addNewRule.Parameters.Add(new SqlParameter("@ExpressionOperator", SqlDbType.Int, 4, "ExpressionOperator"));
            addNewRule.Parameters.Add(new SqlParameter("@QuestionID", SqlDbType.Int, 4, "QuestionID"));
            addNewRule.Parameters.Add(new SqlParameter("@AnswerID", SqlDbType.Int, 4, "AnswerID"));
            addNewRule.Parameters.Add(new SqlParameter("@TargetPageNumber", SqlDbType.Int, 4, "TargetPageNumber"));
            addNewRule.Parameters.Add(new SqlParameter("@TextFilter", SqlDbType.NVarChar, 4000, "TextFilter"));
            addNewRule.Parameters.Add(new SqlParameter("@ConditionalOperator", SqlDbType.Int, 4, "ConditionalOperator"));
            addNewRule.Parameters.Add(new SqlParameter("@Score", SqlDbType.Int, 4, "Score"));
            addNewRule.Parameters.Add(new SqlParameter("@ScoreMax", SqlDbType.Int, 4, "ScoreMax"));
            addNewRule.Parameters.Add(new SqlParameter("@BranchingRuleID", SqlDbType.Int, 4, "BranchingRuleID"));
            addNewRule.Parameters["@BranchingRuleID"].Direction = ParameterDirection.Output;

            SqlHelper.UpdateDataset(addNewRule, new SqlCommand(), new SqlCommand(), newBranchingRule, "BranchingRules", true);
        }

        /// <summary>
        /// Add a new condition to show a given thank you message
        /// </summary>
        public void AddMessageCondition(MessageConditionData newMessageCondition)
        {
            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand addNewCondition = new SqlCommand("vts_spSurveyMessageConditionAddNew", dbConnection);
            addNewCondition.CommandType = CommandType.StoredProcedure;
            addNewCondition.Parameters.Add(new SqlParameter("@SurveyId", SqlDbType.Int, 4, "SurveyId"));
            addNewCondition.Parameters.Add(new SqlParameter("@MessageConditionalOperator", SqlDbType.Int, 4, "MessageConditionalOperator"));
            addNewCondition.Parameters.Add(new SqlParameter("@QuestionID", SqlDbType.Int, 4, "QuestionID"));
            addNewCondition.Parameters.Add(new SqlParameter("@AnswerID", SqlDbType.Int, 4, "AnswerID"));
            addNewCondition.Parameters.Add(new SqlParameter("@TextFilter", SqlDbType.NVarChar, 4000, "TextFilter"));
            addNewCondition.Parameters.Add(new SqlParameter("@ThankYoumessage", SqlDbType.NVarChar, 4000, "ThankYoumessage"));
            addNewCondition.Parameters.Add(new SqlParameter("@ConditionalOperator", SqlDbType.Int, 4, "ConditionalOperator"));
            addNewCondition.Parameters.Add(new SqlParameter("@ExpressionOperator", SqlDbType.Int, 4, "ExpressionOperator"));
            addNewCondition.Parameters.Add(new SqlParameter("@Score", SqlDbType.Int, 4, "Score"));
            addNewCondition.Parameters.Add(new SqlParameter("@ScoreMax", SqlDbType.Int, 4, "ScoreMax"));
            addNewCondition.Parameters.Add(new SqlParameter("@MessageConditionId", SqlDbType.Int, 4, "MessageConditionId"));
            addNewCondition.Parameters["@MessageConditionId"].Direction = ParameterDirection.Output;

            SqlHelper.UpdateDataset(addNewCondition, new SqlCommand(), new SqlCommand(), newMessageCondition, "MessageConditions", true);
        }

        /// <summary>
        /// Updates a message condition
        /// </summary>
        public void UpdateMessageCondition(MessageConditionData updatedMessageCondition)
        {
            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand updateCondition = new SqlCommand("vts_spSurveyMessageConditionUpdate", dbConnection);
            updateCondition.CommandType = CommandType.StoredProcedure;
            updateCondition.Parameters.Add(new SqlParameter("@MessageConditionID", SqlDbType.Int, 4, "MessageConditionId"));
            updateCondition.Parameters.Add(new SqlParameter("@MessageConditionalOperator", SqlDbType.Int, 4, "MessageConditionalOperator"));
            updateCondition.Parameters.Add(new SqlParameter("@QuestionID", SqlDbType.Int, 4, "QuestionID"));
            updateCondition.Parameters.Add(new SqlParameter("@AnswerID", SqlDbType.Int, 4, "AnswerID"));
            updateCondition.Parameters.Add(new SqlParameter("@TextFilter", SqlDbType.NVarChar, 4000, "TextFilter"));
            updateCondition.Parameters.Add(new SqlParameter("@ThankYoumessage", SqlDbType.NVarChar, 4000, "ThankYoumessage"));
            updateCondition.Parameters.Add(new SqlParameter("@ConditionalOperator", SqlDbType.Int, 4, "ConditionalOperator"));
            updateCondition.Parameters.Add(new SqlParameter("@ExpressionOperator", SqlDbType.Int, 4, "ExpressionOperator"));
            updateCondition.Parameters.Add(new SqlParameter("@Score", SqlDbType.Int, 4, "Score"));
            updateCondition.Parameters.Add(new SqlParameter("@ScoreMax", SqlDbType.Int, 4, "ScoreMax"));

            SqlHelper.UpdateDataset(updateCondition, new SqlCommand(), updateCondition, updatedMessageCondition, "MessageConditions", true);
        }

        /// <summary>
        /// returns the thank you message contions for the given survey
        /// </summary>
        public MessageConditionData GetSurveyMessageConditions(int surveyId)
        {
            MessageConditionData messageCondition = new MessageConditionData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyMessageConditionsGetAll", messageCondition, new string[] { "MessageConditions" }, new SqlParameter("@SurveyID", surveyId));
            return messageCondition;
        }

        /// <summary>
        /// Deletes the message condition
        /// </summary>
        public void DeleteMessageConditionById(int messageConditionId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyMessageConditionDeleteByID", new SqlParameter("@MessageConditionID", messageConditionId));
        }

        /// <summary>
        /// Increment the number of time a survey has been viewed
        /// </summary>
        /// <param name="surveyId">Id of the survey to increment views</param>
        /// <param name="incrementNumber">number of views to add</param>
        public void IncrementSurveyViews(int surveyId, int incrementNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@CountNumber", incrementNumber);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyIncrementViews", spParameters);
        }

        /// <summary>
        /// Increment the number of time the survey's result has been viewed
        /// </summary>
        /// <param name="surveyId">Id of the survey to increment result view</param>
        /// <param name="incrementNumber">number of views to add</param>
        public void IncrementResultsViews(int surveyId, int incrementNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@CountNumber", incrementNumber);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyIncrementResultsViews", spParameters);
        }

        /// <summary>
        /// returns the branching rules for the given page of the survey
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="pageNumber"></param>
        /// <returns></returns>
        public BranchingRuleData GetSurveyPageBranchingRules(int surveyId, int pageNumber)
        {
            BranchingRuleData branchingRule = new BranchingRuleData();

            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@pageNumber", pageNumber);
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyBranchingRuleGetForPage", branchingRule, new string[] { "BranchingRules" }, spParameters);

            return branchingRule;
        }

        /// <summary>
        /// returns the branching rules for the given page with all
        /// their details
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="pageNumber"></param>
        /// <returns></returns>
        public BranchingRuleData GetSurveyPageBranchingRulesDetails(int surveyId, int pageNumber)
        {
            BranchingRuleData branchingRule = new BranchingRuleData();

            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@pageNumber", pageNumber);
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyBranchingRuleGetDetailsForPage", branchingRule, new string[] { "BranchingRules" }, spParameters);

            return branchingRule;

        }

        /// <summary>
        /// returns the branching rules for the given survey
        /// </summary>
        /// <param name="surveyId"></param>
        /// <returns></returns>
        public BranchingRuleData GetSurveyBranchingRules(int surveyId)
        {
            BranchingRuleData branchingRule = new BranchingRuleData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyBranchingRuleGetAll", branchingRule, new string[] { "BranchingRules" }, new SqlParameter("@SurveyID", surveyId));
            return branchingRule;
        }

        /// <summary>
        /// Deletes the branching rules 
        /// </summary>
        public void DeleteBranchingRuleById(int branchingRuleId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyBranchingRuleDeleteByID", new SqlParameter("@BranchingRuleID", branchingRuleId));
        }

        /// <summary>
        /// Update the database with the given survey
        /// </summary>
        /// <param name="updatedSurvey">survey to update, must contain the surveyid</param>
        public void UpdateSurvey(SurveyData updatedSurvey, string languageCode)
        {
            try
            {
                SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
                SqlCommand updateSurvey = new SqlCommand("vts_spSurveyUpdate", dbConnection);
                updateSurvey.CommandType = CommandType.StoredProcedure;
                updateSurvey.Parameters.AddWithValue("@LanguageCode", languageCode);
                updateSurvey.Parameters.Add("@SurveyID", SqlDbType.Int, 4, "SurveyID");
                updateSurvey.Parameters.Add(new SqlParameter("@OpenDate", SqlDbType.DateTime, 8, "OpenDate"));
                updateSurvey.Parameters.Add(new SqlParameter("@CloseDate", SqlDbType.DateTime, 8, "CloseDate"));
                updateSurvey.Parameters.Add("@Title", SqlDbType.NVarChar, 255, "Title");
                updateSurvey.Parameters.Add("@ThankYouMessage", SqlDbType.NVarChar, 4000, "ThankYouMessage");
                updateSurvey.Parameters.Add("@RedirectionURL", SqlDbType.NVarChar, 1024, "RedirectionURL");
                updateSurvey.Parameters.Add("@Archive", SqlDbType.Bit, 1, "Archive");
                updateSurvey.Parameters.Add("@Activated", SqlDbType.Bit, 1, "Activated");
                updateSurvey.Parameters.Add("@ResumeModeID", SqlDbType.Int, 1, "ResumeModeID");
                updateSurvey.Parameters.Add("@NavigationEnabled", SqlDbType.Bit, 1, "NavigationEnabled");
                updateSurvey.Parameters.Add("@ProgressDisplayModeId", SqlDbType.Int, 4, "ProgressDisplayModeId");
                updateSurvey.Parameters.Add("@NotificationModeId", SqlDbType.Int, 4, "NotificationModeId");
                updateSurvey.Parameters.Add("@Scored", SqlDbType.Bit, 1, "Scored");
                updateSurvey.Parameters.Add("@QuestionNumberingDisabled", SqlDbType.Bit, 1, "QuestionNumberingDisabled");
                updateSurvey.Parameters.Add("@DefaultSurvey", SqlDbType.Bit, 1, "DefaultSurvey");
                SqlHelper.UpdateDataset(updateSurvey, new SqlCommand(), updateSurvey, updatedSurvey, "Surveys", true);
            }
            catch (SqlException ex)
            {
                if (ex.Message == "DUPLICATEFOLDER") throw new SurveyExistsFoundException();
                throw;
            }

            if ((NotificationMode)updatedSurvey.Surveys[0].NotificationModeID != NotificationMode.None)
            {
                SqlParameter[] spParameters = new SqlParameter[4];
                spParameters[0] = new SqlParameter("@SurveyId", updatedSurvey.Surveys[0].SurveyId);
                spParameters[1] = new SqlParameter("@EmailFrom", updatedSurvey.Surveys[0].EmailFrom);
                spParameters[2] = new SqlParameter("@EmailTo", updatedSurvey.Surveys[0].EmailTo);
                spParameters[3] = new SqlParameter("@EmailSubject", updatedSurvey.Surveys[0].EmailSubject);
                SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spEmailNotificationSettingsAddNew", spParameters);
            }
            else
            {
                SqlParameter[] spParameters = new SqlParameter[4];
                spParameters[0] = new SqlParameter("@SurveyId", updatedSurvey.Surveys[0].SurveyId);
                SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spEmailNotificationSettingsDelete", spParameters);
            }
        }

        /// <summary>
        /// Get the number of minutes after which the security cookie 
        /// expires
        /// </summary>
        public int GetCookieExpiration(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetCookieExpiration", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return 0;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }

        /// <summary>
        /// Update the cookie expiration time
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="cookieExpires"></param>
        public void UpdateCookieExpiration(int surveyId, int cookieExpires)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@CookieExpires", cookieExpires);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyCookieExpirationUpdate", spParameters);
        }

        /// <summary>
        /// Update the ip expiration time
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="ipExpires"></param>
        public void UpdateIPExpiration(int surveyId, int ipExpires)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@IPExpires", ipExpires);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyIPExpirationUpdate", spParameters);
        }

        /// <summary>
        /// Update the survey access password
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="accessPassword"></param>
        public void UpdateAccessPassword(int surveyId, string accessPassword)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@AccessPassword", accessPassword);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyAccessPasswordUpdate", spParameters);
        }

        /// <summary>
        /// Get the number of minutes after which the security IP 
        /// expires
        /// </summary>
        public int GetIPExpiration(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyIPExpirationGet", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return 0;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }


        /// <summary>
        /// Get the access password of the survey
        /// </summary>
        public string GetSurveyPassword(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyAccessPasswordGet", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return null;
            }
            else
            {
                return scalarValue.ToString();
            }
        }

        /// <summary>
        /// Update the survey only invited status
        /// </summary>
        public void UpdateOnlyInvited(int surveyId, bool onlyInvited)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@OnlyInvited", onlyInvited);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyOnlyInvitedUpdate", spParameters);
        }

        /// <summary>
        /// Update the survey only invited status
        /// </summary>
        public void UpdateSaveTokenUserData(int surveyId, bool saveData)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@SaveData", saveData);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveySaveTokenUserDataUpdate", spParameters);
        }

        /// <summary>
        /// Get the invited status of the survey
        /// </summary>
        public bool IsSurveyEmailInviteOnly(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyOnlyInvitedGet", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return Convert.ToBoolean(scalarValue);
            }
        }

        /// <summary>
        /// Get Save Token User status of the survey
        /// </summary>
        public bool IsSurveySaveTokenUserData(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveySaveTokenUserDataGet", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return Convert.ToBoolean(scalarValue);
            }
        }

        /// <summary>
        /// Updates the survey to a new unAuthentified user action
        /// </summary>
        /// <returns></returns>
        public void UpdateUnAuthentifiedUserActions(int surveyId, int unAuthentifiedUserActionId)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@UnAuthentifiedUserActionId", unAuthentifiedUserActionId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyUpdateUnAuthentifiedUserAction", spParameters);
        }

        /// <summary>
        /// Get the actions that is set for the given survey
        /// </summary>
        public int GetSurveyUnAuthentifiedUserAction(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetUnAuthentifiedUserAction", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return -1;
            }
            else
            {
                return int.Parse(scalarValue.ToString());
            }
        }

        /// <summary>
        /// Returns true if the page has any branching rule
        /// associated with it
        /// </summary>
        public bool HasPageBranching(int surveyId, int pageNumber)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyID", surveyId);
            spParameters[1] = new SqlParameter("@pageNumber", pageNumber);

            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyHasPageBranching", spParameters);
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return true;
            }
        }

        /// <summary>
        /// Returns a list of available progress modes
        /// </summary>
        public ProgressModeData GetSurveyProgressModes()
        {
            ProgressModeData progressModeData = new ProgressModeData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spProgressModeGetAll", progressModeData, new string[] { "ProgressDisplayModes" });
            return progressModeData;
        }

        /// <summary>
        /// Returns a list of available email notification mode
        /// </summary>
        public NotificationModeData GetSurveyNotificationModes()
        {
            NotificationModeData notificationModeData = new NotificationModeData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spNotificationModeGetAll", notificationModeData, new string[] { "NotificationModes" });
            return notificationModeData;
        }

        /// <summary>
        /// Retrieves the options that were setup for the page
        /// </summary>
        public PageOptionData GetSurveyPageOptions(int surveyId, int pageNumber)
        {
            PageOptionData pageOptions = new PageOptionData();
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@pageNumber", pageNumber);
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spPageOptionGetDetails", pageOptions, new string[] { "PageOptions" }, spParameters);
            return pageOptions;
        }

        /// <summary>
        /// Update the options that were setup for the page
        /// </summary>
        public void UpdateSurveyPageOptions(PageOptionData updatedPageOptions)
        {
            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand updatePageOptions = new SqlCommand("vts_spPageOptionUpdate", dbConnection);
            updatePageOptions.CommandType = CommandType.StoredProcedure;
            updatePageOptions.Parameters.Add("@SurveyID", SqlDbType.Int, 4, "SurveyID");
            updatePageOptions.Parameters.Add("@PageNumber", SqlDbType.Int, 4, "PageNumber");
            updatePageOptions.Parameters.Add("@RandomizeQuestions", SqlDbType.Bit, 1, "RandomizeQuestions");
            updatePageOptions.Parameters.Add("@EnableSubmitButton", SqlDbType.Bit, 1, "EnableSubmitButton");
            SqlHelper.UpdateDataset(updatePageOptions, new SqlCommand(), updatePageOptions, updatedPageOptions, "PageOptions");
        }

        /// <summary>
        /// Returns a list of available resume modes
        /// </summary>
        public ResumeModeData GetSurveyResumeModes()
        {
            ResumeModeData resumeModeData = new ResumeModeData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spResumeModeGetAll", resumeModeData, new string[] { "ResumeModes" });
            return resumeModeData;
        }

        /// <summary>
        /// returns the thank you message conditions for the given survey
        /// </summary>
        public MessageConditionData GetSurveyMessageCondition(int messageConditionId)
        {
            MessageConditionData messageCondition = new MessageConditionData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyMessageConditionsGetDetails", messageCondition, new string[] { "MessageConditions" }, new SqlParameter("@MessageConditionId", messageConditionId));
            return messageCondition;
        }

        /// <summary>
        /// Check if survey has been set to be scored
        /// </summary>
        public bool IsSurveyScored(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyIsScored", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return Convert.ToBoolean(scalarValue);
            }
        }

        /// <summary>
        ///	Check if the survey allows multiple submission
        ///	for the same username 
        /// </summary>
        public bool AspSecurityAllowsMultipleSubmissions(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyAllowMultipleASPNetVotes", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return Convert.ToBoolean(scalarValue);
            }
        }

        /// <summary>
        /// Update the security settings
        /// </summary>
        public void UpdateAspSecuritySettings(int surveyId, bool allowMultipleSubmissions)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@AllowMultipleSubmissions", allowMultipleSubmissions);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyUpdateASPNetSubmissions", spParameters);
        }

        /// <summary>
        ///	Check if the survey allows multiple submission
        ///	for the same nsurvey username 
        /// </summary>
        public bool NSurveyAllowsMultipleSubmissions(int surveyId)
        {
            Object scalarValue = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyAllowMultipleNSurveyVotes", new SqlParameter("@SurveyID", surveyId));
            if (scalarValue == null || scalarValue == DBNull.Value)
            {
                return false;
            }
            else
            {
                return Convert.ToBoolean(scalarValue);
            }
        }

        /// <summary>
        /// Update the nsurvey security settings
        /// </summary>
        public void UpdateNSurveySecuritySettings(int surveyId, bool allowMultipleNSurveySubmissions)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@SurveyId", surveyId);
            spParameters[1] = new SqlParameter("@allowMultipleNSurveySubmissions", allowMultipleNSurveySubmissions);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyUpdateNSurveySubmissions", spParameters);
        }

        /// <summary>
        /// Returns all the data need to handle 
        /// and process question / answer piping
        /// </summary>
        public PipeData GetSurveyPipeDataFromQuestionId(int questionId)
        {
            PipeData pipeData = new PipeData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetPipeDataFromQuestionId", pipeData, new string[] { "Questions", "Answers" }, new SqlParameter("@QuestionId", questionId));
            return pipeData;
        }

        /// <summary>
        /// Returns all the survey, questions, answers
        /// for a survey
        /// </summary>
        public NSurveyForm GetFormForExport(int surveyId)
        {
            NSurveyForm surveyForm = new NSurveyForm();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyGetForExport", surveyForm, new string[] { "AnswerType", "RegularExpression", "Survey", "Question", "Answer", "AnswerConnection", "ChildQuestion", "AnswerProperty", "QuestionSectionOption", "QuestionSectionGridAnswer", "Surveylanguage", "MultiLanguageText", "QuestionGroup" }, new SqlParameter("@SurveyId", surveyId));
            return surveyForm;
        }

        /// <summary>
        /// Import the given surveys into the DB
        /// </summary>
        public void ImportSurveys(NSurveyForm importSurveys, int userId, int folderId)
        {
            // Prepare connection and transaction
            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            dbConnection.Open();
            SqlTransaction insertTransaction = dbConnection.BeginTransaction();


            // Setup the insert commands for the survey, answer types, questions and answers
            SqlCommand addNewAnswerType = new AnswerType().GetInsertAnswerTypeCommand(dbConnection, insertTransaction, userId);
            SqlCommand addNewRegularExpression = new RegularExpression().GetInsertRegularExpressionCommand(dbConnection, insertTransaction, userId);
            SqlCommand addNewSurvey = GetInsertSurveyCommand(dbConnection, insertTransaction);
            SqlCommand addNewQuestion = new Question().GetInsertQuestionCommand(dbConnection, insertTransaction);
            SqlCommand addNewChildQuestion = new Question().GetInsertChildQuestionCommand(dbConnection, insertTransaction);
            SqlCommand addNewAnswer = new Answer().GetInsertAnswerCommand(dbConnection, insertTransaction);
            SqlCommand addNewAnswerConnection = new Answer().GetInsertAnswerConnectionCommand(dbConnection, insertTransaction);
            SqlCommand addNewAnswerProperty = new Answer().GetInsertAnswerPropertyCommand(dbConnection, insertTransaction);
            SqlCommand addNewQuestionSection = new Question().GetInsertQuestionSectionCommand(dbConnection, insertTransaction, "");
            SqlCommand addNewQuestionSectionGridAnswers = new Question().GetInsertQuestionSectionGridAnswersCommand(dbConnection, insertTransaction);

            // Save the data in the DB
            try
            {
                importSurveys.Survey[0].FolderId = folderId;
                addNewSurvey.Parameters.Add(new SqlParameter("@MultiLanguageModeId", SqlDbType.Int, 4, "MultiLanguageModeId"));
                addNewSurvey.Parameters.Add(new SqlParameter("@ThankYouMessage", SqlDbType.NVarChar, 4000, "ThankYouMessage"));
                SqlHelper.UpdateDataset(addNewAnswerType, new SqlCommand(), addNewAnswerType, importSurveys, "AnswerType", false);
                SqlHelper.UpdateDataset(addNewRegularExpression, new SqlCommand(), addNewRegularExpression, importSurveys, "RegularExpression", false);
                SqlHelper.UpdateDataset(addNewSurvey, new SqlCommand(), addNewSurvey, importSurveys, "Survey", false);

                // Add Question groups so we can attach them to questions
                var groups = new QuestionGroups();
                var defl = importSurveys.SurveyLanguage.SingleOrDefault(x => x.DefaultLanguage);
                string defaultLang = defl == null ? null : defl.LanguageCode;
                defaultLang = defaultLang ?? "en-US";
                if (defaultLang != null) //Load groups only if default language is not null
                {
                    var existingGroups = groups.GetAll(defaultLang).QuestionGroups;
                    foreach (var qgrp in importSurveys.QuestionGroup
                        .OrderBy(x => x.IsParentGroupIdNull() ? 0 : 1)) //Load parent groups first
                    {
                        var grpHere = existingGroups.FirstOrDefault(x => x.GroupName == qgrp.GroupName);

                        int groupIdHere;
                        if (grpHere == null)
                        {
                            int? parentGroupId = null;
                            if (!qgrp.IsParentGroupIdNull()) //Has Parent Group
                            {
                                var pgrp = importSurveys.QuestionGroup.SingleOrDefault(x => x.Id == qgrp.ParentGroupId);
                                if (pgrp != null)
                                {
                                    var exPar = groups.GetAll(defaultLang).QuestionGroups
                                          .FirstOrDefault(x => x.GroupName == pgrp.GroupName);
                                    if (exPar != null) parentGroupId = exPar.ID;
                                }
                            }
                            groups.AddNewGroup(qgrp.GroupName, parentGroupId, defaultLang);

                            var grt = groups.GetAll(defaultLang).QuestionGroups
                                .FirstOrDefault(x => x.GroupName == qgrp.GroupName);
                            groupIdHere = grt.ID;
                        }
                        else
                        {
                            groupIdHere = grpHere.ID;
                        }
                        importSurveys.Question
                              .Where(x =>!x.IsQuestionGroupIdNull() && (x.QuestionGroupId == qgrp.OldId))
                              .ToList().ForEach(x => x.QuestionGroupId = groupIdHere);

                    }
                }

                SqlHelper.UpdateDataset(addNewQuestion, new SqlCommand(), addNewQuestion, importSurveys, "Question", false);
                SqlHelper.UpdateDataset(addNewAnswer, new SqlCommand(), addNewAnswer, importSurveys, "Answer", false);
                SqlHelper.UpdateDataset(addNewAnswerConnection, new SqlCommand(), addNewAnswerConnection, importSurveys, "AnswerConnection", false);
                SqlHelper.UpdateDataset(addNewChildQuestion, new SqlCommand(), addNewChildQuestion, importSurveys, "ChildQuestion", false);
                SqlHelper.UpdateDataset(addNewAnswerProperty, new SqlCommand(), addNewAnswerProperty, importSurveys, "AnswerProperty", false);
                SqlHelper.UpdateDataset(addNewQuestionSection, new SqlCommand(), addNewQuestionSection, importSurveys, "QuestionSectionOption", false);
                int newSurveyId = importSurveys.Survey[0].SurveyID;

                SqlHelper.UpdateDataset(addNewQuestionSectionGridAnswers, new SqlCommand(), addNewQuestionSectionGridAnswers, importSurveys, "QuestionSectionGridAnswer", false);
                insertTransaction.Commit();
                var multiLanguage = new MultiLanguage();
                foreach (var lang in importSurveys.SurveyLanguage)
                    multiLanguage.UpdateSurveyLanguage(newSurveyId, lang.LanguageCode, lang.DefaultLanguage, Constants.Constants.EntitySurvey);

                var localGroups = groups.GetAll(defaultLang).QuestionGroups;
                foreach (var langText in importSurveys.MultiLanguageText)
                {
                    //Process Survey level
                    if (langText.LanguageMessageTypeId == 10)
                    {
                        var impGrp = importSurveys.QuestionGroup.SingleOrDefault(x => x.OldId == langText.LanguageItemId);
                        if (impGrp != null)
                        {
                            var localGrp = localGroups.SingleOrDefault(x => x.GroupName == impGrp.GroupName);
                            try
                            {
                                if (localGrp != null)
                                    multiLanguage.AddMultiLanguageText(localGrp.ID, langText.LanguageCode, langText.LanguageMessageTypeId, langText.ItemText);
                            }
                            catch (Exception ex) { }
                        }
                    }

                    if (langText.LanguageMessageTypeId == 4 || langText.LanguageMessageTypeId == 5)
                        multiLanguage.AddMultiLanguageText(newSurveyId, langText.LanguageCode, langText.LanguageMessageTypeId, langText.ItemText);

                    if (langText.LanguageMessageTypeId == 3 || langText.LanguageMessageTypeId == 11 || langText.LanguageMessageTypeId == 12)
                        multiLanguage.AddMultiLanguageText(importSurveys.Question.Single(x => x.OldQuestionId == langText.LanguageItemId).QuestionId
                            , langText.LanguageCode, langText.LanguageMessageTypeId, langText.ItemText);

                    if (langText.LanguageMessageTypeId == 1 || langText.LanguageMessageTypeId == 2 || langText.LanguageMessageTypeId == 13)
                        multiLanguage.AddMultiLanguageText(importSurveys.Answer.Single(x => x.OldAnswerId == langText.LanguageItemId).AnswerId
                            , langText.LanguageCode, langText.LanguageMessageTypeId, langText.ItemText);

                }


                dbConnection.Close();
            }
            catch (Exception e)
            {
                throw (e);
            }
        }

        /// <summary>
        /// Increase the current entries number calculated
        /// against the max. quota
        /// </summary>
        public void IncreaseQuotaEntries(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyEntryQuotaIncreaseEntry", new SqlParameter("@SurveyId", surveyId));
        }

        /// <summary>
        /// Resets the current entries number calculated
        /// against the max. quota
        /// </summary>
        public void ResetQuotaEntries(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyEntryQuotaReset", new SqlParameter("@SurveyId", surveyId));
        }

        /// <summary>
        /// Deletes survey's quotas
        /// </summary>
        public void DeleteQuotaSettings(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyEntryDelete", new SqlParameter("@SurveyId", surveyId));
        }

        /// <summary>
        /// Retrieves the quota of the survey
        /// </summary>
        public SurveyEntryQuotaData GetQuotaSettings(int surveyId)
        {
            SurveyEntryQuotaData entryQuota = new SurveyEntryQuotaData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spSurveyEntryQuotaGetDetails", entryQuota, new string[] { "SurveyEntryQuotas" }, new SqlParameter("@SurveyId", surveyId));
            return entryQuota;
        }

        /// <summary>
        /// Updates or creates if it doesnt exists 
        /// quota settings for the survey
        /// </summary>
        public void UpdateQuotaSettings(SurveyEntryQuotaData surveyQuota)
        {
            SqlConnection dbConnection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand updateQuota = new SqlCommand("vts_spSurveyEntryQuotaUpdate", dbConnection);
            updateQuota.CommandType = CommandType.StoredProcedure;
            updateQuota.Parameters.Add(new SqlParameter("@SurveyId", SqlDbType.Int, 4, "SurveyId"));
            updateQuota.Parameters.Add(new SqlParameter("@MaxReachedMessage", SqlDbType.NVarChar, 4000, "MaxReachedMessage"));
            updateQuota.Parameters.Add(new SqlParameter("@MaxEntries", SqlDbType.Int, 4, "MaxEntries"));
            SqlHelper.UpdateDataset(updateQuota, new SqlCommand(), updateQuota, surveyQuota, "SurveyEntryQuotas", true);
        }


        public void SetFolderId(int? folderId, int surveyId)
        {
            SqlParameter[] spParameters = new SqlParameter[2];
            spParameters[0] = new SqlParameter("@FolderId", folderId);
            spParameters[1] = new SqlParameter("@SurveyId", surveyId);

            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, "vts_spSurveySetFolder", spParameters);
        }

        /// <summary>
        /// Disable survey's multi language features
        /// </summary>
        /// <param name="surveyId"></param>
        public void SetFriendlyName(int surveyId, string friendlyName)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure,
                "vts_spSurveyUpdateFriendlyName", new SqlParameter[] { new SqlParameter("@SurveyId", surveyId), new SqlParameter("@FriendlyName", friendlyName) });
        }
    }
}
