namespace Votations.NSurvey.SQLServerDAL
{
    using Microsoft.ApplicationBlocks.Data;
    using System;
    using System.Data;
    using System.Data.SqlClient;
    using Votations.NSurvey.Data;
    using Votations.NSurvey.IDAL;

    /// <summary>
    /// SQL Server DAL implementation.
    /// </summary>
    public class User : IUser
    {
        /// <summary>
        /// Adds a new users to the database
        /// </summary>
        public void AddUser(NSurveyUserData newUser)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spUserAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@UserName", SqlDbType.VarChar, 0xff, "UserName"));
            insertCommand.Parameters.Add(new SqlParameter("@Password", SqlDbType.VarChar, 0xff, "Password"));
            insertCommand.Parameters.Add(new SqlParameter("@PasswordSalt", SqlDbType.VarChar, 0xff, "PasswordSalt"));
            insertCommand.Parameters.Add(new SqlParameter("@LastName", SqlDbType.VarChar, 0xff, "LastName"));
            insertCommand.Parameters.Add(new SqlParameter("@FirstName", SqlDbType.VarChar, 0xff, "FirstName"));
            insertCommand.Parameters.Add(new SqlParameter("@Email", SqlDbType.VarChar, 0xff, "Email"));
            insertCommand.Parameters.Add(new SqlParameter("@UserId", SqlDbType.Int, 4, "UserId"));
            insertCommand.Parameters["@UserId"].Direction = ParameterDirection.Output;
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), newUser, "Users", true);
        }

        /// <summary>
        /// Adds a new users settings to the database
        /// </summary>
        public void AddUserSettings(UserSettingData newUserSettings)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spUserSettingAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@UserId", SqlDbType.Int, 4, "UserId"));
            insertCommand.Parameters.Add(new SqlParameter("@IsAdmin", SqlDbType.Bit, 1, "IsAdmin"));
            insertCommand.Parameters.Add(new SqlParameter("@GlobalSurveyAccess", SqlDbType.Bit, 1, "GlobalSurveyAccess"));
			 
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), newUserSettings, "UserSettings", true);
        }

        /// <summary>
        /// Remove the user 
        /// </summary>
        public void DeleteUserById(int userId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserDelete", new SqlParameter[] { new SqlParameter("@UserID", userId) });
        }

        /// <summary>
        /// Retrieves the number of admins in the database
        /// </summary>
        public int GetAdminCount()
        {
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetAdminCount");
            if ((obj2 != null) && (obj2 != DBNull.Value))
            {
                return int.Parse(obj2.ToString());
            }
            return 0;
        }

        /// <summary>
        /// Retrieves all users from the database
        /// </summary>
        public UserData GetAllUsersList()
        {
            UserData dataSet = new UserData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetList", dataSet, new string[] { "Users" });
            return dataSet;
        }

         /// <summary>
        /// Retrieves all users from the database by filter
        /// </summary>
        public UserData GetAllUsersListByFilter(string UserName = null, string FirstName = null, string LastName = null, string Email = null, int ?Admin = null)
        {
            UserData dataSet = new UserData();
            SqlParameter[] commandParameters = new SqlParameter[] { 
                new SqlParameter("@UserName", UserName), 
                new SqlParameter("@FirstName", FirstName),
                new SqlParameter("@LastName", LastName),
                new SqlParameter("@Email", Email),
                new SqlParameter("@Administrator", Admin),
            };

            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetListByFilter", dataSet, new string[] { "Users" }, commandParameters);
            return dataSet;
        }

       /// <summary>
        /// Retrieves the user if any available
        /// </summary>
        public NSurveyUserData GetNSurveyUserData(string userName, string password)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@UserName", userName), new SqlParameter("@Password", password) };
            NSurveyUserData dataSet = new NSurveyUserData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetData", dataSet, new string[] { "Users", "UserSecurityRights" }, commandParameters);
            return dataSet;
        }

        /// <summary>
        /// Retrieves users details from the database
        /// </summary>
        public NSurveyUserData GetUserById(int userId)
        {
            NSurveyUserData dataSet = new NSurveyUserData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetDetails", dataSet, new string[] { "Users" }, new SqlParameter[] { new SqlParameter("@UserId", userId) });
            return dataSet;
        }

        /// <summary>
        /// Retrieves users id from its username
        /// </summary>
        public int GetUserByIdFromUserName(string userName)
        {
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserGetUserIdFromUserName", new SqlParameter[] { new SqlParameter("@UserName", userName) });
            if ((obj2 != null) && (obj2 != DBNull.Value))
            {
                return int.Parse(obj2.ToString());
            }
            return -1;
        }

        /// <summary>
        /// Retrieves an array of the security rights of the user
        /// </summary>
        /// <param name="userId"></param>
        /// <returns></returns>
        public int[] GetUserSecurityRights(int userId)
        {
            DataSet set = SqlHelper.ExecuteDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserSecurityRightGet", new SqlParameter[] { new SqlParameter("@UserID", userId) });
            int[] numArray = new int[set.Tables[0].Rows.Count];
            for (int i = 0; i < set.Tables[0].Rows.Count; i++)
            {
                numArray[i] = int.Parse(set.Tables[0].Rows[i].ItemArray[0].ToString());
            }
            return numArray;
        }

        /// <summary>
        /// Get user settings 
        /// </summary>
        public UserSettingData GetUserSettings(int userId)
        {
            UserSettingData dataSet = new UserSettingData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserSettingGet", dataSet, new string[] { "UserSettings" }, new SqlParameter[] { new SqlParameter("@UserID", userId) });
            return dataSet;
        }

        /// <summary>
        /// Checks if the given user is an administrator
        /// </summary>
        public bool IsAdministrator(int userId)
        {
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spUserIsAdmin", new SqlParameter[] { new SqlParameter("@UserId", userId) });
            return ((obj2 != null) && (obj2 != DBNull.Value));
        }

        /// <summary>
        /// Updates users data
        /// </summary>
        public void UpdateUser(NSurveyUserData updatedUser)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spUserUpdate", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@UserId", SqlDbType.Int, 4, "UserId"));
            insertCommand.Parameters.Add(new SqlParameter("@UserName", SqlDbType.VarChar, 0xff, "UserName"));
            insertCommand.Parameters.Add(new SqlParameter("@Password", SqlDbType.VarChar, 0xff, "Password"));
            insertCommand.Parameters.Add(new SqlParameter("@PasswordSalt", SqlDbType.VarChar, 0xff, "PasswordSalt"));
            insertCommand.Parameters.Add(new SqlParameter("@LastName", SqlDbType.VarChar, 0xff, "LastName"));
            insertCommand.Parameters.Add(new SqlParameter("@FirstName", SqlDbType.VarChar, 0xff, "FirstName"));
            insertCommand.Parameters.Add(new SqlParameter("@Email", SqlDbType.VarChar, 0xff, "Email"));
            SqlHelper.UpdateDataset(insertCommand,new SqlCommand(), insertCommand , updatedUser, "Users", true);
        }

        /// <summary>
        /// Updates users settings
        /// </summary>
        public void UpdateUserSettings(UserSettingData updatedUserSettings)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand updateCommand = new SqlCommand("vts_spUserSettingUpdate", connection);
            updateCommand.CommandType = CommandType.StoredProcedure;
            updateCommand.Parameters.Add(new SqlParameter("@UserId", SqlDbType.Int, 4, "UserId"));
            updateCommand.Parameters.Add(new SqlParameter("@IsAdmin", SqlDbType.Bit, 1, "IsAdmin"));
            updateCommand.Parameters.Add(new SqlParameter("@GlobalSurveyAccess", SqlDbType.Bit, 1, "GlobalSurveyAccess"));

            SqlHelper.UpdateDataset(updateCommand, new SqlCommand(), updateCommand, updatedUserSettings, "UserSettings", true);
        }
    }
}

