namespace Votations.NSurvey.SQLServerDAL
{
    using Microsoft.ApplicationBlocks.Data;
    using System;
    using System.Data;
    using System.Data.SqlClient;
    using System.Runtime.InteropServices;
    using Votations.NSurvey.Data;
    using Votations.NSurvey.IDAL;
    using System.Linq;

    /// <summary>
    /// SQL Server DAL implementation.
    /// </summary>
    public class Voter : IVoter
    {
        /// <summary>
        /// Add a new voter and his answers to the database 
        /// </summary>
        public void AddVoter(VoterAnswersData voterAnswers)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            connection.Open();
            SqlTransaction transaction = connection.BeginTransaction();
            SqlCommand insertCommand = new SqlCommand("vts_spVoterAddNew", connection, transaction);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@SurveyID", SqlDbType.Int, 4, "SurveyID"));
            insertCommand.Parameters.Add(new SqlParameter("@IPSource", SqlDbType.NVarChar, 50, "IPSource"));
            insertCommand.Parameters.Add(new SqlParameter("@VoteDate", SqlDbType.DateTime, 8, "VoteDate"));
            insertCommand.Parameters.Add(new SqlParameter("@StartDate", SqlDbType.DateTime, 8, "StartDate"));
            insertCommand.Parameters.Add(new SqlParameter("@Validated", SqlDbType.Bit, 1, "Validated"));
            insertCommand.Parameters.Add(new SqlParameter("@UId", SqlDbType.VarChar, 50, "UId"));
            insertCommand.Parameters.Add(new SqlParameter("@VoterID", SqlDbType.Int, 4, "VoterID"));
            insertCommand.Parameters.Add(new SqlParameter("@ResumeUId", SqlDbType.VarChar, 50, "ResumeUId"));
            insertCommand.Parameters.Add(new SqlParameter("@ProgressSaveDate", SqlDbType.DateTime, 8, "ProgressSaveDate"));
            insertCommand.Parameters.Add(new SqlParameter("@ResumeAtPageNumber", SqlDbType.Int, 4, "ResumeAtPageNumber"));
            insertCommand.Parameters.Add(new SqlParameter("@ResumeQuestionNumber", SqlDbType.Int, 4, "ResumeQuestionNumber"));
            insertCommand.Parameters.Add(new SqlParameter("@ResumeHighestPageNumber", SqlDbType.Int, 4, "ResumeHighestPageNumber"));
            insertCommand.Parameters.Add(new SqlParameter("@LanguageCode", SqlDbType.VarChar, 50, "LanguageCode"));
            insertCommand.Parameters["@VoterID"].Direction = ParameterDirection.Output;
            SqlCommand command2 = new SqlCommand("vts_spVoterAnswersAddNew", connection, transaction);
            command2.CommandType = CommandType.StoredProcedure;
            command2.Parameters.Add(new SqlParameter("@AnswerID", SqlDbType.Int, 4, "AnswerID"));
            command2.Parameters.Add(new SqlParameter("@AnswerText", SqlDbType.NText, 0x3fffffff, "AnswerText"));
            command2.Parameters.Add(new SqlParameter("@VoterID", SqlDbType.Int, 4, "VoterID"));
            command2.Parameters.Add(new SqlParameter("@SectionNumber", SqlDbType.Int, 4, "SectionNumber"));
            try
            {
                SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), insertCommand, voterAnswers, "Voters", false);
                SqlHelper.UpdateDataset(command2, new SqlCommand(), command2, voterAnswers, "VotersAnswers", false);
                transaction.Commit();
                connection.Close();
            }
            catch (Exception exception)
            {
                transaction.Rollback();
                throw exception;
            }
        }

        public void ImportVoter(int SurveyId,NSurveyVoter voterImport)
        {
          //QuestionIdText and AnsweridText must be supplied for every answer
 
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            connection.Open();
            SqlTransaction transaction = connection.BeginTransaction();
            for (int voterIndex = 0; voterIndex < voterImport.Voter.Count; voterIndex++)
            {
                var voter = voterImport.Voter[voterIndex];
                voter.SurveyID = SurveyId;
                //Create a new structure with voter and answers for the voter
                NSurveyVoter voterAnswers = new NSurveyVoter();
                voterAnswers.EnforceConstraints = false;

                voterAnswers.Voter.ImportRow(voter);
                voterAnswers.Answer.Columns.Add("SurveyId", typeof(int));
                voterAnswers.Answer.Columns.Add("QuestionText", typeof(string));
                var answers = voterImport.Answer.Where(x => x.VoterId == voter.VoterID).ToList();
                for (int answerIndex = 0; answerIndex < answers.Count(); answerIndex++)
                {
                    var currAnswer = answers[answerIndex];
                    voterAnswers.Answer.ImportRow(currAnswer);
                }

                foreach (var dr in voterAnswers.Answer)
                {
                   dr["QuestionText"] = voterImport.Question.Single(x => x.QuestionId == dr.QuestionId &&
                                                        x.VoterID == dr.VoterId).QuestionText;
                    dr["SurveyId"] = SurveyId;
                }

                SqlCommand insertCommand = new SqlCommand("vts_spVoterImport", connection, transaction);
                insertCommand.CommandType = CommandType.StoredProcedure;
                insertCommand.Parameters.Add(new SqlParameter("@SurveyID", SqlDbType.Int, 4, "SurveyID"));
                insertCommand.Parameters.Add(new SqlParameter("@IPSource", SqlDbType.NVarChar, 50, "IPSource"));
                insertCommand.Parameters.Add(new SqlParameter("@VoteDate", SqlDbType.DateTime, 8, "VoteDate"));
                insertCommand.Parameters.Add(new SqlParameter("@VoterID", SqlDbType.Int, 4, "VoterID"));
                insertCommand.Parameters.Add(new SqlParameter("@StartDate", SqlDbType.DateTime, 8, "StartDate"));

                insertCommand.Parameters.Add(new SqlParameter("@LanguageCode", SqlDbType.NVarChar, 50, "LanguageCode"));

                insertCommand.Parameters["@VoterID"].Direction = ParameterDirection.Output;
                SqlCommand command2 = new SqlCommand("vts_spVoterAnswersImport", connection, transaction);
               
                command2.CommandType = CommandType.StoredProcedure;
                command2.Parameters.Add(new SqlParameter("@Answer", SqlDbType.NText, 0x3fffffff, "Answer"));
                command2.Parameters.Add(new SqlParameter("@VoterAnswer", SqlDbType.NText, 0x3fffffff, "VoterAnswer"));
                command2.Parameters.Add(new SqlParameter("@VoterID", SqlDbType.Int, 4, "VoterID"));
                command2.Parameters.Add(new SqlParameter("@QuestionDisplayOrder", SqlDbType.Int, 4, "QuestionDisplayOrder"));
                command2.Parameters.Add(new SqlParameter("@AnswerDisplayOrder", SqlDbType.Int, 4, "AnswerDisplayOrder"));
                command2.Parameters.Add(new SqlParameter("@SectionNumber", SqlDbType.Int, 4, "SectionNumber"));
                command2.Parameters.Add(new SqlParameter("@SurveyId", SqlDbType.Int, 4, "SurveyId"));
                command2.Parameters.Add(new SqlParameter("@QuestionText", SqlDbType.NVarChar, 4000, "QuestionText"));
                try
                {
                    SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), insertCommand, voterAnswers, "Voter", false);
                    int voterId = voterAnswers.Voter[0].VoterID;
                    foreach (var dr in voterAnswers.Answer) dr.VoterId = voterId;
                    SqlHelper.UpdateDataset(command2, new SqlCommand(), command2, voterAnswers, "Answer", false);
                }

                catch (Exception exception)
                {
                    transaction.Rollback();
                    throw ;
                }
            }
            transaction.Commit();
            connection.Close();
        }

        /// <summary>
        /// Queue an invitation request for a future voter
        /// </summary>
        public void AddVoterInvitation(int surveyId, string email, bool anonymousEntry, string UId)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@Email", email), new SqlParameter("@AnonymousEntry", anonymousEntry), new SqlParameter("@Uid", UId) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationQueueAddNew", commandParameters);
        }

        /// <summary>
        /// 
        /// Checks if the given IP has already been registered
        /// in the expiration time lapse
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="voterIP"></param>
        /// <param name="IPExpires"></param>
        /// <returns></returns>
        public bool CheckIfVoterIPExists(int surveyId, string voterIP)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@SurveyID", surveyId);
            commandParameters[1] = new SqlParameter("@IP", voterIP);
            if (SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterCheckIfIPExists", commandParameters) == null)
            {
                return false;
            }
            return true;
        }

        /// <summary>
        /// Checks if the given UID has already been registered
        /// </summary>
        /// <returns></returns>
        public bool CheckIfVoterUIdExists(int surveyId, string uId)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@SurveyID", surveyId);
            commandParameters[1] = new SqlParameter("@UID", uId);
            if (SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterCheckIfUIDExists", commandParameters) == null)
            {
                return false;
            }
            return true;
        }

        /// <summary>
        /// Deletes the log of the invitation
        /// </summary>
        /// <param name="invitationLogId"></param>
        public void DeleteInvitationLog(int invitationLogId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spInvitationLogDelete", new SqlParameter[] { new SqlParameter("@InvitationLogId", invitationLogId) });
        }

        /// <summary>
        /// Deletes all unvalidated entries
        /// </summary>
        public void DeleteUnvalidatedVoters(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeleteUnvalidated", new SqlParameter[] { new SqlParameter("@SurveyId", surveyId) });
        }

        /// <summary>
        /// Delete all answer a voter gave for the survey
        /// </summary>
        public void DeleteVoterAnswers(int voterId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeleteAnswers", new SqlParameter[] { new SqlParameter("@voterId", voterId) });
        }

        /// <summary>
        /// Delete a voter and all its answers
        /// </summary>
        /// <param name="voterId"></param>
        /// <returns></returns>
        public void DeleteVoterById(int voterId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDelete", new SqlParameter[] { new SqlParameter("@VoterId", voterId) });
        }

        /// <summary>
        /// Deletes the email from the survey invitation queue
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="emailId"></param>
        public void DeleteVoterInvitation(int surveyId, int emailId)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@EmailID", emailId) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationQueueDelete", commandParameters);
        }

        /// <summary>
        /// Deletes the email from the survey invitation queue
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="emailId"></param>
        public void DeleteVoterInvitation(int surveyId, string email)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@Email", email) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationQueueDeleteByEmail", commandParameters);
        }

        /// <summary>
        /// Delete all answer a voter gave for the page
        /// </summary>
        public void DeleteVoterPageAnswers(int surveyId, int voterId, int pageNumber)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyId", surveyId), new SqlParameter("@VoterId", voterId), new SqlParameter("@PageNumber", pageNumber) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeletePageAnswers", commandParameters);
        }

        /// <summary>
        /// Delete all answer a voter gave for the question
        /// </summary>
        public void DeleteVoterQuestionAnswers(int voterId, int questionId)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@VoterId", voterId);
            commandParameters[1] = new SqlParameter("@QuestionId", questionId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeleteQuestionAnswers", commandParameters);
        }

        /// <summary>
        /// Deletes a voter resume session
        /// from the database
        /// </summary>
        public void DeleteVoterResumeSession(int surveyId, string resumeUId)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@SurveyId", surveyId);
            commandParameters[1] = new SqlParameter("@ResumeUID", resumeUId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeleteResumeSession", commandParameters);
        }

        /// <summary>
        /// Delete all voter and all its answers for the survey
        /// </summary>
        /// <param name="surveyId"></param>
        /// <returns></returns>
        public void DeleteVoters(int surveyId)
        {
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterDeleteAll", new SqlParameter[] { new SqlParameter("@SurveyID", surveyId) });
        }

        /// <summary>
        /// Get number of voters for the given date
        /// </summary>
        public int GetDayStats(int surveyId, DateTime statDay)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyId", surveyId), new SqlParameter("@StatDay", statDay) };
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetDailyStat", commandParameters);
            if ((obj2 != null) && (obj2 != DBNull.Value))
            {
                return int.Parse(obj2.ToString());
            }
            return 0;
        }

        /// <summary>
        /// returns the guid from the queue for the given email and survey id
        /// </summary>
        public string GetEmailUId(int surveyId, string email)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@Email", email) };
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationQueueGetUId", commandParameters);
            if (obj2 == null)
            {
                return null;
            }
            return obj2.ToString();
        }

        /// <summary>
        /// Returns all data needed to create a CSV
        /// </summary>
        public CSVExportData GetForCSVExport(int surveyId, DateTime startDate, DateTime endDate)
        {
            CSVExportData dataSet = new CSVExportData();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@StartDate", startDate), new SqlParameter("@EndDate", endDate) };
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterExportCSVData ", dataSet, new string[] { "ExportAnswers", "Voters", "VoterAnswers" }, commandParameters);
            return dataSet;
        }

        /// <summary>
        /// Returns all the answers of the voters
        /// </summary>
        public NSurveyVoter GetForExport(int surveyId, DateTime startDate, DateTime endDate)
        {
            NSurveyVoter dataSet = new NSurveyVoter();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@StartDate", startDate), new SqlParameter("@EndDate", endDate) };
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterForExport ", dataSet, new string[] { "Voter", "Question", "Answer" }, commandParameters);
            return dataSet;
        }

        /// <summary>
        /// Returns all the invitation logs
        /// </summary>
        public InvitationLogData GetInvitationLogs(int surveyId, int pageNumber, int pageSize, out int totalRecords)
        {
            InvitationLogData dataSet = new InvitationLogData();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@CurrentPage", pageNumber), new SqlParameter("@PageSize", pageSize), new SqlParameter("@TotalRecords", SqlDbType.Int) };
            commandParameters[3].Direction = ParameterDirection.Output;
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spInvitationLogGetAll", dataSet, new string[] { "InvitationLogs" }, commandParameters);
            totalRecords = int.Parse(commandParameters[3].Value.ToString());
            return dataSet;
        }

        /// <summary>
        /// Get voter's statistics for the given month and year
        /// </summary>
        public VoterStatisticsData GetMonthlyStats(int surveyId, int month, int year)
        {
            VoterStatisticsData dataSet = new VoterStatisticsData();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@Month", month), new SqlParameter("@Year", year) };
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spvoterGetMonthlyStats", dataSet, new string[] { "VoterStats" }, commandParameters);
            return dataSet;
        }

        /// <summary>
        /// returns the number of unvalidated entries (saved progress)
        /// </summary>
        public int GetUnvalidatedVotersCount(int surveyId)
        {
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetUnvalidatedCount", new SqlParameter[] { new SqlParameter("@SurveyId", surveyId) });
            if (obj2 == null)
            {
                return 0;
            }
            return int.Parse(obj2.ToString());
        }

        /// <summary>
        /// Get voter's answers and voter details
        /// </summary>
        /// <param name="voterId"></param>
        /// <returns></returns>
        public VoterAnswersData GetVoterAnswers(int voterId)
        {
            VoterAnswersData dataSet = new VoterAnswersData();
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetAnswers", dataSet, new string[] { "Voters", "VotersAnswers" }, new SqlParameter[] { new SqlParameter("@VoterID", voterId) });
            return dataSet;
        }

        /// <summary>
        /// Returns all the entries text / selections of the voters
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="pageNumber"></param>
        /// <param name="pageSize"></param>
        /// <param name="startDate"></param>
        /// <param name="endDate"></param>
        /// <returns></returns>
        public DataSet GetVotersCompleteEntries(int surveyId, int pageNumber, int pageSize, DateTime startDate, DateTime endDate)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@CurrentPage", pageNumber), new SqlParameter("@PageSize", pageSize), new SqlParameter("@StartDate", startDate), new SqlParameter("@EndDate", endDate) };
            return SqlHelper.ExecuteDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetFullPivot", commandParameters);
        }

        /// <summary>
        /// Returns all voters who have answered an invitation 
        /// </summary>
        public VoterData GetVotersInvitationAnswered(int surveyId, int pageNumber, int pageSize, out int totalRecords)
        {
            VoterData dataSet = new VoterData();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@CurrentPage", pageNumber), new SqlParameter("@PageSize", pageSize), new SqlParameter("@TotalRecords", SqlDbType.Int) };
            commandParameters[3].Direction = ParameterDirection.Output;
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationAnsweredGetAll", dataSet, new string[] { "Voters" }, commandParameters);
            totalRecords = int.Parse(commandParameters[3].Value.ToString());
            return dataSet;
        }

        /// <summary>
        /// Returns the invitation queue of the survey
        /// </summary>
        public InvitationQueueData GetVotersInvitationQueue(int surveyId, int pageNumber, int pageSize, out int totalRecords)
        {
            InvitationQueueData dataSet = new InvitationQueueData();
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@CurrentPage", pageNumber), new SqlParameter("@PageSize", pageSize), new SqlParameter("@TotalRecords", SqlDbType.Int) };
            commandParameters[3].Direction = ParameterDirection.Output;
            SqlHelper.FillDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterInvitationQueueGetAll", dataSet, new string[] { "InvitationQueues" }, commandParameters);
            totalRecords = int.Parse(commandParameters[3].Value.ToString());
            return dataSet;
        }

        /// <summary>
        /// Returns all the text entries of the voters
        /// </summary>
        /// <param name="surveyId"></param>
        /// <param name="pageNumber"></param>
        /// <param name="pageSize"></param>
        /// <param name="startDate"></param>
        /// <param name="endDate"></param>
        /// <returns></returns>
        public DataSet GetVotersTextEntries(int surveyId, int pageNumber, int pageSize, DateTime startDate, DateTime endDate)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@CurrentPage", pageNumber), new SqlParameter("@PageSize", pageSize), new SqlParameter("@StartDate", startDate), new SqlParameter("@EndDate", endDate) };
            return SqlHelper.ExecuteDataset(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetPivotTextEntries", commandParameters);
        }

        /// <summary>
        /// Check if the username has already taken the survey
        /// </summary>
        public bool HasUserNameVoted(int surveyId, string userName)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@SurveyId", surveyId);
            commandParameters[1] = new SqlParameter("@UserName", userName);
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterGetByUserName", commandParameters);
            return ((obj2 != null) && (obj2 != DBNull.Value));
        }

        /// <summary>
        /// Check if the given Uid is valid
        /// </summary>
        /// <param name="UId"></param>
        /// <returns>returns the Survey id of the Uid if its valid else returns -1</returns>
        public int IsUIdValid(string UId)
        {
            object obj2 = SqlHelper.ExecuteScalar(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spInvitationUidIsValid", new SqlParameter[] { new SqlParameter("@UId", UId) });
            if (obj2 == null)
            {
                return -1;
            }
            return int.Parse(obj2.ToString());
        }

        /// <summary>
        /// logs the exception that occured for the invitation in the db
        /// </summary>
        public void LogInvitationError(InvitationLogData invitationLog)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            SqlCommand insertCommand = new SqlCommand("vts_spInvitationLogAddNew", connection);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@SurveyID", SqlDbType.Int, 4, "SurveyID"));
            insertCommand.Parameters.Add(new SqlParameter("@Email", SqlDbType.NVarChar, 0x9b, "Email"));
            insertCommand.Parameters.Add(new SqlParameter("@ExceptionMessage", SqlDbType.NVarChar, 0x400, "ExceptionMessage"));
            insertCommand.Parameters.Add(new SqlParameter("@ExceptionType", SqlDbType.NVarChar, 0xff, "ExceptionType"));
            insertCommand.Parameters.Add(new SqlParameter("@ErrorDate", SqlDbType.DateTime, 8, "ErrorDate"));
            insertCommand.Parameters.Add(new SqlParameter("@InvitationLogId", SqlDbType.Int, 4, "InvitationLogId"));
            insertCommand.Parameters["@InvitationLogId"].Direction = ParameterDirection.Output;
            insertCommand.Parameters.Add(new SqlParameter("@EmailId", SqlDbType.Int, 4, "EmailId"));
            insertCommand.Parameters["@EmailId"].Direction = ParameterDirection.Output;
            SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), new SqlCommand(), invitationLog, "InvitationLogs", true);
        }

        /// <summary>
        /// Get the voter's data and answers to resume a session
        /// </summary>
        public VoterAnswersData ResumeVoterAnswers(int surveyId, string resumeUid)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@SurveyID", surveyId), new SqlParameter("@ResumeUid", resumeUid) };
            VoterAnswersData dataSet = new VoterAnswersData();
            SqlHelper.FillDatasetWithoutChangesAccept(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterResumeSession", dataSet, new string[] { "Voters", "VotersAnswers" }, commandParameters);
            return dataSet;
        }

        /// <summary>
        /// Set the give uid to the voter
        /// </summary>
        public void SetVoterUId(int voterId, string uId)
        {
            SqlParameter[] commandParameters = new SqlParameter[3];
            commandParameters[0] = new SqlParameter("@VoterId", voterId);
            commandParameters[1] = new SqlParameter("@UID", uId);
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterUIdAddNew", commandParameters);
        }

        /// <summary>
        /// Updates voter's answer
        /// </summary>
        /// <param name="voterAnswers">Voter and all his answers information</param>
        public void UpdateVoter(VoterAnswersData updatedVoterAnswers)
        {
            SqlConnection connection = new SqlConnection(SqlHelper.DbConnectionString);
            connection.Open();
            SqlTransaction transaction = connection.BeginTransaction();
            SqlCommand insertCommand = new SqlCommand("vts_spVoterAnswersAddNew", connection, transaction);
            insertCommand.CommandType = CommandType.StoredProcedure;
            insertCommand.Parameters.Add(new SqlParameter("@AnswerID", SqlDbType.Int, 4, "AnswerID"));
            insertCommand.Parameters.Add(new SqlParameter("@AnswerText", SqlDbType.NText, 0x3fffffff, "AnswerText"));
            insertCommand.Parameters.Add(new SqlParameter("@VoterID", SqlDbType.Int, 4, "VoterID"));
            insertCommand.Parameters.Add(new SqlParameter("@SectionNumber", SqlDbType.Int, 4, "SectionNumber"));
            try
            {
                SqlHelper.ExecuteNonQuery(transaction, CommandType.StoredProcedure, "vts_spVoterDeleteAnswers", new SqlParameter[] { new SqlParameter("@voterId", updatedVoterAnswers.Voters[0].VoterId) });
                SqlHelper.UpdateDataset(insertCommand, new SqlCommand(), insertCommand, updatedVoterAnswers, "VotersAnswers", false);
                transaction.Commit();
                connection.Close();
            }
            catch (Exception exception)
            {
                transaction.Rollback();
                throw exception;
            }
        }

        /// <summary>
        /// Update the asp.net username of the voter
        /// </summary>
        public void UpdateVoterUserName(int voterId, string userName)
        {
            SqlParameter[] commandParameters = new SqlParameter[] { new SqlParameter("@VoterId", voterId), new SqlParameter("@UserName", userName) };
            SqlHelper.ExecuteNonQuery(SqlHelper.DbConnectionString, CommandType.StoredProcedure, "vts_spVoterUpdateUserName", commandParameters);
        }
    }
}

